% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/env.R
\name{env_assign}
\alias{env_assign}
\alias{env_bind}
\alias{env_define}
\title{Assign objects to an environment.}
\usage{
env_assign(env = caller_env(), nm, x)

env_bind(env = caller_env(), data = list())

env_define(env = caller_env(), ...)
}
\arguments{
\item{env}{An environment or an object bundling an environment:
either a \link{quosure} or a \link[=is_closure]{closure}. If
missing, the environment of the current evaluation frame is
returned.}

\item{nm}{The name of the binding.}

\item{x}{The value of the binding.}

\item{data}{Uniquely named bindings. See \code{\link[=is_dictionaryish]{is_dictionaryish()}}.
Dots have \link[=dots_list]{explicit-splicing semantics}.}

\item{...}{Pairs of unique names and R objects used to define new
bindings.}
}
\value{
The input object \code{env}, with its associated environment
modified in place.
}
\description{
These functions create bindings in the specified environment. The
bindings are supplied as pairs of names and values, either directly
(\code{env_assign()}), in dots (\code{env_define()}), or from a dictionary
(\code{env_bind()}). See \code{\link[=is_dictionaryish]{is_dictionaryish()}} for the definition of a
dictionary.
}
\details{
These functions operate by side effect. For example, if you assign
bindings to a closure function, the environment of the function is
modified in place.
}
\examples{
# Create a function that uses undefined bindings:
fn <- with_env(child_env("base"), function() list(a, b, c, d, e))

# This would throw a scoping error if run:
# fn()

data <- set_names(letters, letters)
env_bind(fn, data)

# fn() now sees the objects
fn()

# Redefine new bindings:
fn <- env_assign(fn, "a", "1")
fn <- env_define(fn, b = "2", c = "3")
fn()
}
